# Generated by Django 5.2.10 on 2026-03-15 12:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "django_resaas",
            "0006_alter_theme_options_layoutsetting_border_radius_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="layoutsetting",
            name="nome",
            field=models.CharField(max_length=101),
        ),
    ]
